summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/codecs/tqrtlcodec.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/codecs/tqrtlcodec.cpp')
-rw-r--r--tqtinterface/qt4/src/codecs/tqrtlcodec.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/tqtinterface/qt4/src/codecs/tqrtlcodec.cpp b/tqtinterface/qt4/src/codecs/tqrtlcodec.cpp
index 56bf40d..a5640aa 100644
--- a/tqtinterface/qt4/src/codecs/tqrtlcodec.cpp
+++ b/tqtinterface/qt4/src/codecs/tqrtlcodec.cpp
@@ -291,9 +291,9 @@ static TQString reverseLine(const TQString &str, unsigned int from, unsigned int
* "SHALOM my friend" or "my friend SHALOM", depending on the basic direction
* one assumes for the text.
*
* So this function uses some heuristics to tqfind the right answer...
*/
-static TQChar::Direction tqfindBasicDirection(TQString str)
+static TQChar::Direction findBasicDirection(TQString str)
{
unsigned int pos;
unsigned int len = str.length();
@@ -421,7 +421,7 @@ const char* TQHebrewCodec::mimeName() const
static TQString visualOrder(TQString logical, TQChar::Direction basicDir)
{
- logical.tqreplace(TQChar('\n'), TQChar(0x2028));
+ logical.replace(TQChar('\n'), TQChar(0x2028));
#ifdef USE_QT4
// [FIXME]
@@ -471,8 +471,8 @@ static TQString visualOrder(TQString logical, TQChar::Direction basicDir)
}
visual += sub;
}
- // tqreplace Unicode newline back with \n to compare.
- visual.tqreplace(TQChar(0x2028), TQChar('\n'));
+ // replace Unicode newline back with \n to compare.
+ visual.replace(TQChar(0x2028), TQChar('\n'));
if (l != levels) {
delete [] levels;
delete [] visualOrder;
@@ -542,7 +542,7 @@ TQString TQHebrewCodec::toUnicode(const char* chars, int len ) const
// do transformation from visual byte ordering to logical byte
// ordering
if( basicDir == TQChar::DirON )
- basicDir = tqfindBasicDirection(r);
+ basicDir = findBasicDirection(r);
return visualOrder(r, basicDir);
}
@@ -291,9 +291,9 @@ static TQString reverseLine(const TQString &str, unsigned int from, unsigned int
* one assumes for the text.
*
- * So this function uses some heuristics to tqfind the right answer...
+ * So this function uses some heuristics to find the right answer...
*/